.. HMC MIR documentation master file, created by
   sphinx-quickstart on Thu May 25 16:26:21 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to HMC MIR's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
